---
title: Installing from source
menu:
  docs:
    weight: 20
    parent: admin
---

## Pre-requisites <a id="pre-requisites"></a>

* A machine running **Ubuntu 18.04** that you have root access to
* A **domain name** \(or a subdomain\) for the Mastodon server, e.g. `example.com`
* An e-mail delivery service or other **SMTP server**

You will be running the commands as root. If you aren’t already root, switch to root:

### System repositories <a id="system-repositories"></a>

Make sure curl is installed first:

#### Node.js <a id="node-js"></a>

```bash
curl -sL https://deb.nodesource.com/setup_8.x | bash -
```

#### Yarn <a id="yarn"></a>

```bash
curl -sS https://dl.yarnpkg.com/debian/pubkey.gpg | apt-key add -
echo "deb https://dl.yarnpkg.com/debian/ stable main" | tee /etc/apt/sources.list.d/yarn.list
```

### System packages <a id="system-packages"></a>

```bash
apt update
apt install -y \
  imagemagick ffmpeg libpq-dev libxml2-dev libxslt1-dev file git-core \
  g++ libprotobuf-dev protobuf-compiler pkg-config nodejs gcc autoconf \
  bison build-essential libssl-dev libyaml-dev libreadline6-dev \
  zlib1g-dev libncurses5-dev libffi-dev libgdbm5 libgdbm-dev \
  nginx redis-server redis-tools postgresql postgresql-contrib \
  certbot python-certbot-nginx yarn libidn11-dev libicu-dev libjemalloc-dev
```

### Installing Ruby <a id="installing-ruby"></a>

We will be using rbenv to manage Ruby versions, because it’s easier to get the right versions and to update once a newer release comes out. rbenv must be installed for a single Linux user, therefore, first we must create the user Mastodon will be running as:

```bash
adduser --disabled-login mastodon
```

We can then switch to the user:

And proceed to install rbenv and rbenv-build:

```bash
git clone https://github.com/rbenv/rbenv.git ~/.rbenv
cd ~/.rbenv && src/configure && make -C src
echo 'export PATH="$HOME/.rbenv/bin:$PATH"' >> ~/.bashrc
echo 'eval "$(rbenv init -)"' >> ~/.bashrc
exec bash
git clone https://github.com/rbenv/ruby-build.git ~/.rbenv/plugins/ruby-build
```

Once this is done, we can install the correct Ruby version:

```bash
RUBY_CONFIGURE_OPTS=--with-jemalloc rbenv install 2.6.1
rbenv global 2.6.1
```

Default gem version shipped with ruby\_2.6.0 is incompatible with latest bundler, so we need to update gem:

```bash
gem update --system
```

We’ll also need to install bundler:

```bash
gem install bundler --no-document
```

Return to the root user:

## Setup <a id="setup"></a>

### Setting up PostgreSQL <a id="setting-up-postgresql"></a>

#### Performance configuration \(optional\) <a id="performance-configuration-optional"></a>

For optimal performance, you may use [pgTune](https://pgtune.leopard.in.ua/#/) to generate an appropriate configuration and edit values in `/etc/postgresql/9.6/main/postgresql.conf` before restarting PostgreSQL with `systemctl restart postgresql`

#### Creating a user <a id="creating-a-user"></a>

You will need to create a PostgreSQL user that Mastodon could use. It is easiest to go with “ident” authentication in a simple setup, i.e. the PostgreSQL user does not have a separate password and can be used by the Linux user with the same username.

Open the prompt:

In the prompt, execute:

```sql
CREATE USER mastodon CREATEDB;
\q
```

Done!

### Setting up Mastodon <a id="setting-up-mastodon"></a>

It is time to download the Mastodon code. Switch to the mastodon user:

#### Checking out the code <a id="checking-out-the-code"></a>

Use git to download the latest stable release of Mastodon:

```bash
git clone https://github.com/tootsuite/mastodon.git live && cd live
git checkout $(git tag -l | grep -v 'rc[0-9]*$' | sort -V | tail -n 1)
```

#### Installing the last dependencies <a id="installing-the-last-dependencies"></a>

Now to install Ruby and JavaScript dependencies:

```bash
bundle install \
  -j$(getconf _NPROCESSORS_ONLN) \
  --deployment --without development test
yarn install --pure-lockfile
```

#### Generating a configuration <a id="generating-a-configuration"></a>

Run the interactive setup wizard:

```bash
RAILS_ENV=production bundle exec rake mastodon:setup
```

This will:

* Create a configuration file
* Run asset precompilation
* Create the database schema

The configuration file is saved as `.env.production`. You can review and edit it to your liking. Refer to the [documentation on configuration.]({{< relref "config.md" >}})

You’re done with the mastodon user for now, so switch back to root:

### Setting up nginx <a id="setting-up-nginx"></a>

Copy the configuration template for nginx from the Mastodon directory:

```bash
cp /home/mastodon/live/dist/nginx.conf /etc/nginx/sites-available/mastodon
ln -s /etc/nginx/sites-available/mastodon /etc/nginx/sites-enabled/mastodon
```

Then edit `/etc/nginx/sites-available/mastodon` to replace `example.com` with your own domain name, and make any other adjustments you might need.

Reload nginx for the changes to take effect:

### Acquiring a SSL certificate <a id="acquiring-a-ssl-certificate"></a>

We’ll use Let’s Encrypt to get a free SSL certificate:

```bash
certbot --nginx -d example.com
```

This will obtain the certificate, automatically update `/etc/nginx/sites-available/mastodon` to use the new certificate, and reload nginx for the changes to take effect.

At this point you should be able to visit your domain in the browser and see the elephant hitting the computer screen error page. This is because we haven’t started the Mastodon process yet.

### Setting up systemd services <a id="setting-up-systemd-services"></a>

Copy the systemd service templates from the Mastodon directory:

```bash
cp /home/mastodon/live/dist/mastodon-*.service /etc/systemd/system/
```

Then edit the files to make sure the username and paths are correct:

* `/etc/systemd/system/mastodon-web.service`
* `/etc/systemd/system/mastodon-sidekiq.service`
* `/etc/systemd/system/mastodon-streaming.service`

Finally, start and enable the new systemd services:

```bash
systemctl start mastodon-web mastodon-sidekiq mastodon-streaming
systemctl enable mastodon-*
```

They will now automatically start at boot time.

{{< hint style="success" >}}
**Hurray! This is it. You can visit your domain in the browser now!**
{{< /hint >}}

